<?php

namespace Test\Ease;

use Ease\User;

/**
 * Generated by PHPUnit_SkeletonGenerator on 2016-01-17 at 23:58:22.
 */
class UserTest extends AnonymTest {

    /**
     * @var User
     */
    protected $object;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp(): void {
        $this->object = new User();
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown(): void {
        
    }

    /**
     * Test Constructor
     *
     * @covers Ease\User::__construct
     */
    public function testConstructor() {
        $classname = get_class($this->object);

        // Get mock, without the constructor being called
        $mock = $this->getMockBuilder($classname)
                ->disableOriginalConstructor()
                ->getMockForAbstractClass();
        $mock->__construct('test', ['debug' => false]);

        $this->assertEmpty($mock->getData());
    }

    /**
     * @covers Ease\User::getUserName
     */
    public function testGetUserName() {
        $this->object->setDataValue('login', 'vitex');
        $this->assertEquals('vitex', $this->object->getUserName());
    }

    /**
     * @covers Ease\User::getUserEmail
     * @covers Ease\Person::getUserEmail
     */
    public function testGetUserEmail() {
        $this->object->setDataValue('email', 'info@vitexsoftware.cz');
        $this->assertEquals('info@vitexsoftware.cz', $this->object->getUserEmail());
    }

    /**
     * @covers Ease\User::draw
     */
    public function testDraw($whatWant = null) {
        $this->assertEquals('<img class="avatar" src="">', $this->object->draw());
    }

    /**
     * @covers Ease\User::getIcon
     */
    public function testGetIcon() {
        $this->assertEmpty($this->object->getIcon());
        $this->object->setDataValue('email', 'info@vitexsoftware.cz');
        $this->assertEquals('http://www.gravatar.com/avatar/f00226a1c6fe891010a2543531ed432c?s=800&d=mm&r=g', $this->object->getIcon());
    }

    /**
     * @covers Ease\User::tryToLogin
     */
    public function testTryToLogin() {
        $this->assertEmpty($this->object->tryToLogin([]));
        $this->assertEmpty($this->object->tryToLogin(['login' => 'noone']));
        $this->assertEmpty($this->object->tryToLogin(['login' => '', 'password' => '']));
        $this->assertFalse($this->object->logged, $this->object->tryToLogin(['login' => 'vitex', 'password' => 'secret']));
    }

    /**
     * @covers Ease\User::isAccountEnabled
     */
    public function testIsAccountEnabled() {
        $this->assertTrue($this->object->isAccountEnabled());
        $this->object->disableColumn = 'state';
        $this->object->setDataValue('state', true);
        $this->assertFalse($this->object->isAccountEnabled());
        $this->object->setDataValue('state', false);
        $this->assertTrue($this->object->isAccountEnabled());
    }

    /**
     * @covers Ease\User::loginSuccess
     */
    public function testLoginSuccess() {
        $this->object->loginSuccess();
        $this->assertTrue($this->object->logged);
    }

    /**
     * @covers Ease\User::authentize
     */
    public function testAuthentize() {
        $this->assertFalse($this->object->authentize('pass'));
    }

    /**
     * @covers Ease\User::validatePassword
     */
    public function testValidatePassword() {
        $this->object->setDataValue('password', '240885b263943a74849aa0b2d3b1285b:2d');
        $this->assertTrue($this->object->validatePassword('password'));
    }

    /**
     * @covers Ease\User::encryptPassword
     */
    public function testEncryptPassword() {
        $this->assertFalse(empty(\Ease\User::encryptPassword('password')));
    }

    /**
     * @covers Ease\User::passwordValidation
     */
    public function testPasswordValidation() {
        $this->assertFalse(\Ease\User::passwordValidation('heslo', '813c98b71749197010bb458facd84021'));
        $this->assertTrue(\Ease\User::passwordValidation('password', '240885b263943a74849aa0b2d3b1285b:2d'));
    }

    /**
     * @covers Ease\User::passwordValidation
     * @covers Ease\User::encryptPassword
     */
    public function testPassword() {
        $encrypted = \Ease\User::encryptPassword('password');
        $this->assertNotEmpty($encrypted);
        $this->assertTrue(\Ease\User::passwordValidation('password', $encrypted));

        $this->assertFalse(\Ease\User::passwordValidation('X', $encrypted));

        $this->assertFalse(\Ease\User::passwordValidation('X', 'x:x:x'));
    }

    /**
     * @covers Ease\User::passwordChange
     */
    public function testPasswordChange() {
        $this->assertFalse($this->object->passwordChange('newpass'));
    }

    /**
     * @covers Ease\User::getUserID
     */
    public function testGetUserID() {
        $this->assertEquals(0, $this->object->getUserID());
    }

    /**
     * @covers Ease\User::getUserLogin
     * @covers Ease\User::setUserLogin
     */
    public function testUserLogin() {
        $this->assertTrue($this->object->setUserLogin('vitex'));
        $this->assertEquals('vitex', $this->object->getUserLogin());
    }

    /**
     * @covers Ease\User::getPermission
     */
    public function testGetPermission() {
        $this->assertEquals('', $this->object->getPermission());
    }

    /**
     * @covers Ease\User::logout
     */
    public function testLogout() {
        $this->assertTrue($this->object->logout());
        $this->assertFalse($this->object->logged);
    }

    /**
     * @a
     * @covers Ease\User::getSettingValue
     */
    public function testGetSettingValue() {
        $this->object->setSettingValue('test', 'tested');
        $this->assertEquals('tested', $this->object->getSettingValue('test'));
    }

    /**
     * @covers Ease\User::setSettings
     */
    public function testSetSettings() {
        $this->object->setSettings(['key' => 'value']);
        $this->assertEquals('value', $this->object->getSettingValue('key'));
    }

    /**
     * @covers Ease\User::setSettingValue
     */
    public function testSetSettingValue() {
        $this->object->setSettingValue('test', 'tested');
        $this->assertEquals('tested', $this->object->getSettingValue('test'));
    }

    /**
     * @covers Ease\User::loadPermissions
     */
    public function testLoadPermissions() {
        $this->assertEquals('', $this->object->loadPermissions());
    }

    /**
     * @covers Ease\User::getName
     */
    public function testGetName() {
        $this->assertEquals('Ease\User:@127.0.0.1 [tester]', $this->object->getName());
    }

    /**
     * @covers Ease\User::getGravatar
     */
    public function testGetGravatar() {
        $this->assertEquals('http://www.gravatar.com/avatar/f00226a1c6fe891010a2543531ed432c?s=80&d=mm&r=g', $this->object->getGravatar('info@vitexsoftware.cz'));
    }

    /**
     * @covers Ease\User::setObjectName
     */
    public function testSetObjectName() {
        $this->assertEquals('Ease\User:@127.0.0.1 [tester]', $this->object->setObjectName());
    }

}
